
require "sketchup.rb"

module ProperTool

	#Observer
	class ProperTool::ViewObserver < Sketchup::ViewObserver
		def onViewChanged(view)
			puts "View changed: #{view}"
		end
	end

	#Create observer
	version="ProperTool_002"
	unless file_loaded?(version)
		ProperTool::VERSION=version
		@@view_observer=ProperTool::ViewObserver.new
	end

	#Define reader method for the observer
	def ProperTool::get_view_observer
		return @@view_observer
	end

	#Tool
	class ProperTool::TestTool
		def initialize(web_dialog)
			"Tool created."
			@web_dialog=web_dialog
		end

		def activate
			puts "Tool activated."
		end

		def onCancel(reason,view)
			@web_dialog.close
		end

		def deactivate(view)
			@web_dialog.close
		end
	end

	#Web Dialog controls the rest
	class ProperTool::MainDialog

		def initialize

			@dlg=UI::WebDialog.new("FlashTest", false ,"FlashTest", 510, 700, 150, 150, false)
			#@dlg.set_full_security(false)

			html_path = Sketchup.find_support_file("flash-js-test.html","Plugins/")
			@dlg.set_file html_path

			@dlg.set_on_close {
				puts "Set on close fired."
				Sketchup.active_model.active_view.remove_observer ProperTool::get_view_observer
				Sketchup.active_model.select_tool(nil)
			}

			@dlg.add_action_callback('close_me'){ |dialog, params| self.close() }

			@tool = Sketchup.active_model.select_tool ProperTool::TestTool.new(@dlg)
			Sketchup.active_model.active_view.add_observer ProperTool::get_view_observer
			@dlg.show_modal

		end

		def close
			@dlg.close
		end

	end

end # Module

unless file_loaded?(ProperTool::VERSION)
		main_menu = UI.menu("Plugins")
		main_menu.add_item("ProperTool") {ProperTool::MainDialog.new}
end

file_loaded(ProperTool::VERSION)